# Superdesk Production API Server

This server is used to provide stable and versioned endpoints for third-party apps to consume news content from Superdesk.

The documentation is available in `/docs` directory, or can be checked at https://superdesk.readthedocs.org/.
